@@ -8,24 +8,23 @@
 #' Attention : conserver le meme ordre des pop-up dans le vecteur que celui des
 #' donnees pour que les valeurs correspondent bien a l'analyse.
 #'
+#' Ne fonctionne que pour les ronds proportionnels, les analyses en classes et les typologies.
+#'
 #' Pour supprimer les pop-up, laisser le parametre a NULL.
 #'
-#' @usage set_pop_up(map, popupRonds = NULL, popupClasses = NULL)
+#' @usage set_pop_up(map, popup = NULL, popupRonds = NULL)
 #'
 #' @param map objet leaflet.
+#' @param popup vecteur de caracteres (character). Peut etre du HTML pour
+#' mettre en forme le texte. Par defaut a NULL.
 #' @param popupRonds vecteur de caracteres (character). Peut etre du HTML pour
 #' mettre en forme le texte. Par defaut a NULL.
-#' @param popupClasses vecteur de caracteres (character). Peut etre du HTML
-#' pour mettre en forme le texte. Par defaut a NULL.
 #'
 #' @return Retourne un objet de type leaflet.
 #'
 #' @seealso \code{\link{leaflet_ronds}, \link{leaflet_classes},
 #' \link{leaflet_ronds_classes}, \link{leaflet_classes_ronds},
-#' \link{leaflet_typo},}
-#'
-#' \code{\link{leaflet_oursins}, \link{leaflet_joignantes},
-#' \link{leaflet_saphirs}}
+#' \link{leaflet_typo}}
 #'
 #' @keywords documentation
 #'
@@ -69,13 +68,13 @@
 #' @export set_pop_up
 #'
 set_pop_up <-
-function(map,popupRonds=NULL,popupClasses=NULL)
+function(map,popup=NULL,popupRonds=NULL)
   {
     msg_error1<-msg_error2<-msg_error3 <- NULL
 
     if(any(!any(class(map) %in% "leaflet"), !any(class(map) %in% "htmlwidget"))) msg_error1 <- "La carte doit etre un objet leaflet / "
-    if(!is.null(popupRonds)) if(any(class(popupRonds)!="character")) msg_error2 <- "Le parametre popupRonds doit etre un vecteur de caractere (contenu html possible) / "
-    if(!is.null(popupClasses)) if(any(class(popupClasses)!="character")) msg_error3 <- "Le parametre popupClasses doit etre un vecteur de caractere (contenu html possible) / "
+    if(!is.null(popup)) if(any(class(popup)!="character")) msg_error2 <- "Le parametre popup doit etre un vecteur de caractere (contenu html possible) / "
+    if(!is.null(popupRonds)) if(any(class(popupRonds)!="character")) msg_error3 <- "Le parametre popupRonds doit etre un vecteur de caractere (contenu html possible) / "
 
     if(any(!is.null(msg_error1),!is.null(msg_error2),!is.null(msg_error3)))
     {
@@ -86,9 +85,9 @@ function(map,popupRonds=NULL,popupClasses=NULL)
     idx_carte_ronds <- NULL
     for(i in 1:length(map$x$calls))
     {
-      if(map$x$calls[[i]]$method %in% "addPolygons")
+      if(map$x$calls[[i]]$method %in% c("addPolygons","addPolylines"))
       {
-        if(map$x$calls[[i]]$args[[3]] %in% c("carte_classes","carte_classes_elargi"))
+        if(map$x$calls[[i]]$args[[3]] %in% c("carte_classes","carte_classes_elargi","carte_typo"))
         {
           idx_carte_classes <- c(idx_carte_classes,i)
         }
@@ -104,12 +103,12 @@ function(map,popupRonds=NULL,popupClasses=NULL)
 
     if(length(idx_carte_classes)==2)
     {
-      map$x$calls[[idx_carte_classes[1]]]$args[[5]] <- popupClasses
+      map$x$calls[[idx_carte_classes[1]]]$args[[5]] <- popup
       length_analyse <- length(map$x$calls[[idx_carte_classes[2]]]$args[[5]])
-      map$x$calls[[idx_carte_classes[2]]]$args[[5]] <- popupClasses[1:length_analyse]
+      map$x$calls[[idx_carte_classes[2]]]$args[[5]] <- popup[1:length_analyse]
     }else if(length(idx_carte_classes)==1)
     {
-      map$x$calls[[idx_carte_classes[1]]]$args[[5]] <- popupClasses
+      map$x$calls[[idx_carte_classes[1]]]$args[[5]] <- popup
     }
 
     if(length(idx_carte_ronds)==2)
